@@ -1,9 +1,9 @@
 /****************************************************************/
 /* gsmart300.c - Gphoto2 library for the Mustek gSmart 300      */
 /*                                                              */
-/* Copyright (C) 2002 Jrme Lodewyck                           */
+/* Copyright (C) 2002 Jérôme Lodewyck                           */
 /*                                                              */
-/* Author: Jrme Lodewyck <jerome.lodewyck@ens.fr>             */
+/* Author: Jérôme Lodewyck <jerome.lodewyck@ens.fr>             */
 /*                                                              */
 /* based on code by: Till Adam <till@adam-lilienthal.de>        */
 /*                                                              */
@@ -21,17 +21,20 @@
 /*                                                              */
 /* You should have received a copy of the GNU Library General   */
 /* Public License along with this library; if not, write to the */
-/* Free Software Foundation, Inc., 59 Temple Place - Suite 330, */
-/* Boston, MA 02111-1307, USA.                                  */
+/* Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,*/
+/* Boston, MA  02110-1301  USA					*/
 /****************************************************************/
 
+#define _BSD_SOURCE
+
 #include <config.h>
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include <gphoto2.h>
-#include <gphoto2-endian.h>
+#include <unistd.h>
+#include <gphoto2/gphoto2.h>
+#include "gphoto2-endian.h"
 
 #include "gsmart300.h"
 #include "gsmart300-jpeg-header.h"
@@ -60,9 +63,9 @@ static int gsmart300_download_data (CameraPrivateLibrary * lib,
 		int data_type, uint16_t index, unsigned int size,
 		uint8_t * buf);
 static int gsmart300_get_FATs (CameraPrivateLibrary * lib);
-static int yuv2rgb (int y, int u, int v, int *r, int *g, int *b);
+static int yuv2rgb (int y, int u, int v, unsigned int *r, unsigned int *g, unsigned int *b);
 static int gsmart300_get_image_thumbnail (CameraPrivateLibrary * lib,
-				       uint8_t ** buf, unsigned int *len,
+				       CameraFile *file,
 				       struct GsmartFile *g_file);
 
 #define __GS300_FAT		0
@@ -70,10 +73,10 @@ static int gsmart300_get_image_thumbnail (CameraPrivateLibrary * lib,
 #define __GS300_PIC		2
 #define __GS300_INIT		3
 
-int
+static int
 gsmart300_get_file_count (CameraPrivateLibrary * lib)
 {
-	char buf[0x100];
+	uint8_t buf[0x100];
 
 	gsmart300_download_data (lib, __GS300_INIT,  0, 0x100, buf);
 	lib->num_files = (buf[21] >> 4) * 10 + (buf[21] & 0xf)
@@ -116,14 +119,14 @@ gsmart300_delete_all (CameraPrivateLibrary * lib)
 }
 
 int
-gsmart300_request_file (CameraPrivateLibrary * lib, uint8_t ** buf,
-		     unsigned int *len, unsigned int number)
+gsmart300_request_file (CameraPrivateLibrary * lib, CameraFile *file,
+		     unsigned int number)
 {
 	struct GsmartFile *g_file;
 	uint8_t *p, *lp_jpg, *start_of_file;
 	uint8_t qIndex, value;
 	uint8_t *mybuf;
-	int i;
+	int i, ret;
 	/* NOTE : these varialbes are slightly renamed */
 	int flash_size, data_size, file_size;
 
@@ -145,13 +148,19 @@ gsmart300_request_file (CameraPrivateLibrary * lib, uint8_t ** buf,
 	if (!mybuf)
 		return GP_ERROR_NO_MEMORY;
 
-	CHECK (gsmart300_download_data (lib, __GS300_PIC, g_file->index,
-				        flash_size, mybuf));
+	ret = gsmart300_download_data (lib, __GS300_PIC, g_file->index,
+				        flash_size, mybuf);
+	if (ret < GP_OK) {
+		free (mybuf);
+		return ret;
+	}
 
 	/* now build a jpeg */
 	lp_jpg = malloc (file_size);
-	if (!lp_jpg)
+	if (!lp_jpg) {
+		free (mybuf);
 		return GP_ERROR_NO_MEMORY;
+	}
 	start_of_file = lp_jpg;
 
 	/* copy the header from the template */
@@ -188,42 +197,38 @@ gsmart300_request_file (CameraPrivateLibrary * lib, uint8_t ** buf,
 	*(lp_jpg++) = 0xFF;
 	*(lp_jpg++) = 0xD9;
 	free (mybuf);
-	file_size = lp_jpg - start_of_file;
-	start_of_file = realloc (start_of_file, file_size);
-	*buf = start_of_file;
-	*len = file_size;
-
+	gp_file_append (file, (char*)start_of_file, lp_jpg - start_of_file);
+	free (start_of_file);
 	return (GP_OK);
 }
 
 int
-gsmart300_request_thumbnail (CameraPrivateLibrary * lib, uint8_t ** buf,
-			  unsigned int *len, unsigned int number, int *type)
+gsmart300_request_thumbnail (CameraPrivateLibrary * lib, CameraFile *file,
+			  unsigned int number, int *type)
 {
 	struct GsmartFile *g_file;
 
 	CHECK (gsmart300_get_file_info (lib, number, &g_file));
 
 	*type = g_file->mime_type;
-	return (gsmart300_get_image_thumbnail (lib, buf, len, g_file));
+	return (gsmart300_get_image_thumbnail (lib, file, g_file));
 }
 
 
 
 static int
-gsmart300_get_image_thumbnail (CameraPrivateLibrary * lib, uint8_t ** buf,
-			    unsigned int *len, struct GsmartFile *g_file)
+gsmart300_get_image_thumbnail (CameraPrivateLibrary * lib, CameraFile *file,
+			    struct GsmartFile *g_file)
 {
 	unsigned int size;
-	uint8_t *p;
 	uint8_t *mybuf = NULL;
-	uint8_t *tmp;
+	uint8_t *tmp, *buf;
 	unsigned int t_width, t_height;
-	uint8_t *yuv_p;
-	uint8_t *rgb_p;
-	unsigned char pbm_header[14];
+	uint8_t *yuv_p, *rgb_p;
+	uint32_t len;
+	char pbm_header[14];
+	int ret;
 
-	p = g_file->fat;
 
 	/* No thumbnail for 320x240 pictures */
 	if (g_file->width < 640)
@@ -238,21 +243,27 @@ gsmart300_get_image_thumbnail (CameraPrivateLibrary * lib, uint8_t ** buf,
 	size = 9728;
 
 	mybuf = malloc (size);
-	CHECK (gsmart300_download_data (lib, __GS300_THUMB, g_file->index,
-				        size, mybuf));
-
+	if (!mybuf)
+		return (GP_ERROR_NO_MEMORY);
+	ret = gsmart300_download_data (lib, __GS300_THUMB, g_file->index,
+				        size, mybuf);
+	if (ret < GP_OK) {
+		free (mybuf);
+		return ret;
+	}
 	/* effective size of file */
 	size = 9600;
 
-	*len = t_width * t_height * 3 + sizeof (pbm_header);
-	*buf = malloc (*len);
-	if (!*buf)
+	len = t_width * t_height * 3;
+	buf = malloc (len);
+	if (!buf) {
+		free (mybuf);
 		return (GP_ERROR_NO_MEMORY);
+	}
 
-	tmp = *buf;
-	snprintf (tmp, sizeof (pbm_header), pbm_header);
-	tmp += sizeof (pbm_header) - 1;
+	gp_file_append (file, pbm_header, strlen(pbm_header));
 
+	tmp = buf;
 	yuv_p = mybuf;
 	rgb_p = tmp;
 	while (yuv_p < mybuf + size) {
@@ -276,8 +287,9 @@ gsmart300_get_image_thumbnail (CameraPrivateLibrary * lib, uint8_t ** buf,
 
 		yuv_p += 4;
 	}
-
 	free (mybuf);
+	gp_file_append (file, (char*)buf, len);
+	free (buf);
 	return (GP_OK);
 }
 
@@ -342,7 +354,7 @@ static int gsmart300_download_data (CameraPrivateLibrary * lib, int data_type,
 	}
 
 	for (i = 0; i < size >> 8; i++)
-		CHECK (gp_port_read (lib->gpdev, buf + i*0x100, 0x100));
+		CHECK (gp_port_read (lib->gpdev, (char*)(buf + i*0x100), 0x100));
 
 	return GP_OK;
 }
@@ -354,7 +366,7 @@ gsmart300_get_FATs (CameraPrivateLibrary * lib)
 	unsigned int index = 0;
 	unsigned int file_index = 0;
 	uint8_t *p = NULL;
-	uint8_t buf[14];
+	char buf[14];
 
 	CHECK (gsmart300_get_file_count(lib));
 
@@ -394,7 +406,7 @@ gsmart300_get_FATs (CameraPrivateLibrary * lib)
 }
 
 static int
-yuv2rgb (int y, int u, int v, int *_r, int *_g, int *_b)
+yuv2rgb (int y, int u, int v, unsigned int *_r, unsigned int *_g, unsigned int *_b)
 {
 	double r, g, b;
 
