@@ -1,9 +1,13 @@
+#define _BSD_SOURCE
+#define _POSIX_C_SOURCE 199309L
+
 #include "config.h"
 
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
 #include <time.h>
+#include <unistd.h>
 
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port.h>
@@ -301,15 +305,12 @@ static int camera_capture (Camera *camera, CameraCaptureType type, CameraFilePat
 	gp_list_get_name (list, count - 1, &name);
 	gp_list_free(list);
 
-
 	/* Set the filename */
-	snprintf(path->folder, sizeof(path->folder), "/");
-	
+	strcpy(path->folder, "/");
 
 	CHECK_RESULT (gp_filesystem_append (camera->fs, 
 					    path->folder, 
 					    path->name, context));
-
         return (GP_OK);
 
 }
@@ -413,7 +414,7 @@ int camera_init (Camera *camera, GPContext *context) {
         gp_port_send_break (camera->port, 2);
 
         /* Wait for it to update */
-        GP_SYSTEM_SLEEP(1500);
+        usleep(1500 * 1000);
 
 	if (dc120_set_speed (camera, speed) == GP_ERROR) {
                 return (GP_ERROR);
