@@ -4,13 +4,12 @@
        Hubert Figuiere <hfiguiere@teaser.fr>
  */
 
-#define _POSIX_C_SOURCE 199309L
-
 #include "config.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
 #include <gphoto2/gphoto2.h>
 #include <gphoto2/gphoto2-port.h>
@@ -131,7 +130,7 @@ static int dc240_packet_write (Camera *camera, unsigned char *packet, int size,
 write_again:
     /* If retry, give camera some recup time */
     if (x > 0) {
-        GP_SYSTEM_SLEEP(SLEEP_TIMEOUT);
+        usleep(SLEEP_TIMEOUT * 1000);
     }
 
     /* Return error if too many retries */
@@ -239,7 +238,7 @@ static int dc240_wait_for_busy_completion (Camera *camera)
 	BUSY_RETRIES = 100
     };
     unsigned char p[8];
-    int retval;
+    int retval = 0;
     int x=0, done=0;
 
     /* Wait for command completion */
@@ -510,7 +509,7 @@ int dc240_set_speed (Camera *camera, int speed)
     if (retval != GP_OK)
         goto fail;
 
-    GP_SYSTEM_SLEEP(300);
+    usleep(300 * 1000);
     retval = dc240_wait_for_completion(camera);
     if (retval != GP_OK)
 	goto fail;
