@@ -1,6 +1,7 @@
 /* sierra_usbwrap.c
  *
- * Copyright  2002 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright 2002 Lutz Mueller <lutz@users.sourceforge.net>
+ * Copyright 2012-2013 Marcus Meissner <marcus@jet.franken.de>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,14 +15,18 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  * 
  *
  * Olympus C-3040Z (and possibly also the C-2040Z and others) have
  * a USB PC Control mode in which "Sierra" protocol packets are tunneled
  * inside another protocol.  This file implements the wrapper protocol.
  * The (ab)use of USB clear halt is not needed for this protocol.
+ * 
+ * The other protocol is "SCSI via USB Mass Storage", so we can also use
+ * the Linux SCSI APIs. Interesting is also that the header looks a bit
+ * like a PTP header.
  *
  * IMPORTANT: In order to use this mode, the camera must be switched
  * _out_ of "USB Mass Storage" mode and into "USB PC control mode".
@@ -33,6 +38,9 @@
  * access door (the camera senses this) and then press and hold
  * both of the menu buttons until the camera control menu appears.
  * Set it to ON.  This disables the USB mass-storage support.
+ *
+ * Update 20110125: This switching might not be necessary with the new code,
+ * please just try.
  */
 
 #include "config.h"
@@ -90,28 +98,6 @@ cmdbyte (unsigned int type, unsigned char nr) {
 #define UW_EQUAL(a, b) \
 ((a).c1==(b).c1 && (a).c2==(b).c2 && (a).c3==(b).c3 && (a).c4==(b).c4)
 
-/*
- * USB wrapper packets start with ASCII bytes "USBC".
- * The responses back from the camera start with "USBS".
- */
-#define UW_MAGIC_OUT ((uw4c_t){ 'U','S','B','C' })
-#define UW_MAGIC_IN  ((uw4c_t){ 'U','S','B','S' })
-
-static void
-make_uw_request(uw4c_t *req,
-	unsigned char inout, unsigned char a,
-	unsigned char len, unsigned char cmd
-) {
-	req->c1 = inout;
-	req->c2 = a;
-	req->c3 = len;
-	req->c4 = cmd;
-}
-
-#define MAKE_UW_REQUEST_OUT(req, a, b) make_uw_request (req, 0x00, 0x00, a, b) /* write to camera */
-#define MAKE_UW_REQUEST_IN(req, a, b) make_uw_request (req, 0x80, 0x00, a, b)  /* read from camera */
-/* Move REQUEST_STAT calls to write_packet %%% */
-
 /*
  * Each of the following request types begins with USBC+SessionID and
  * ends with a response from the camera of USBS+SessionID (OK).
@@ -138,23 +124,37 @@ make_uw_request(uw4c_t *req,
 #define UW_PACKET_DATA ((uw4c_t){ 0x02, 0x00, 0xff, 0x9f })
 #define UW_PACKET_STAT ((uw4c_t){ 0x03, 0x00, 0xff, 0x9f })
 
+#define UW_MAGIC_OUT ((uw4c_t){ 'U','S','B','C' })
+#define UW_MAGIC_IN  ((uw4c_t){ 'U','S','B','S' })
+
 #pragma pack(1)
-/*
- * The rest of the USB wrapper packet looks like this:
- */
+/* This is linux/include/linux/usb/storage.h, struct bulk_cb_wrap
+ * 31 byte length */
 typedef struct
 {
-      uw4c_t magic;    /* The letters U S B C for packets sent to camera */
-      uw32_t sessionid;        /* Any 32-bit handle the host wants (maybe not 0?) */
-      uw32_t rw_length;        /* Length of data to be read or written next */
-      uw4c_t request_type;     /* One of the UW_REQUEST_* defines */
-      char   zero[3];          /* 00 00 00 ? */
-      char   req_camid_len;    /* 00 (or 0x22 if camera id request) */
-      char   zero2[4];         /* 00 00 00 ? */
-      uw32_t length;           /* Length of transaction repeated? */
-      char      zero3[3];      /* 00 00 00 */
+      uw4c_t magic;             /* The letters U S B C for packets sent to camera */
+      uw32_t tag;               /* The SCSI command tag */
+      uw32_t rw_length;         /* Length of data to be read or written next */
+      unsigned char flags;      /* in / out flag mostly */
+      unsigned char lun;        /* 0 here */
+      unsigned char length;     /* of the CDB... but 0x0c is used here in the traces */
+      unsigned char cdb[16];    
 } uw_header_t;
 
+/*
+ * This is the end response block from the camera looks like this:
+ *
+ * This is the generic bulk style USB Storage response block.
+ *
+ * linux/include/linux/usb/storage.h, struct bulk_cs_wrap */
+typedef struct
+{
+      uw4c_t magic;     /* The letters U S B S for packets from camera */
+      uw32_t tag;       /* A copy of whatever value the host made up */
+      uw32_t residue;   /* residual read? */
+      char   status;    /* status byte */
+} uw_response_t;
+
 /*
  * Data packet sent along with a UW_REQUEST_RDY:
  */
@@ -196,122 +196,152 @@ typedef struct
       uw32_t size;             /* The size of data waiting to be sent by camera */
 } uw_size_t;
 
-/*
- * The end of the response from the camera looks like this:
- */
 typedef struct
 {
-      uw4c_t magic;    /* The letters U S B S for packets from camera */
-      uw32_t sessionid;        /* A copy of whatever value the host made up */
-      char   zero[5];  /* 00 00 00 00 00 */
-} uw_response_t;
+      unsigned char cmd;
+      char   zero1[8];
+      uw32_t length;
+      char   zero2[3];
+} uw_scsicmd_t;
 #pragma pack()
 
-/*
- * This routine is called after every UW_REQUEST_XXX to get an OK
- * with a matching session ID.
- */
+static int ums_tag = 0x42424242;
+
 static int
-usb_wrap_OK (GPPort *dev, uw_header_t *hdr, unsigned int type)
-{
-   uw_response_t rsp;
-   int ret;
-   memset(&rsp, 0, sizeof(rsp));
+scsi_wrap_cmd(
+	GPPort *dev, int todev,
+	char *cmd, unsigned int cmdlen,
+	char *sense, unsigned int senselen,
+	char *data, unsigned int size
+) {
+	GPPortInfo	info;
+	GPPortType	type;
+	uw_header_t	hdr;
+	uw_response_t	rsp;
+	int		ret;
 
-   GP_DEBUG( "usb_wrap_OK" );
+	ret = gp_port_get_info (dev, &info);
+	if (ret != GP_OK) return ret;
 
-   if ((ret = gp_port_read(dev, (char*)&rsp, sizeof(rsp))) != sizeof(rsp))
-   {
-      GP_DEBUG( "gp_port_read *** FAILED" );
-      if (ret < GP_OK)
-	return ret;
-      return GP_ERROR;
-   }
+	ret = gp_port_info_get_type (info, &type);
+	if (ret != GP_OK) return ret;
 
-   if (!UW_EQUAL(rsp.magic, UW_MAGIC_IN) ||
-       !UW_EQUAL(rsp.sessionid, hdr->sessionid))
-   {
-      GP_DEBUG( "usb_wrap_OK wrong session *** FAILED" );
-      return GP_ERROR;
-   }
+	if (type == GP_PORT_USB_SCSI)
+		/* just send it to the generic SCSI stack */
+		return gp_port_send_scsi_cmd (
+			dev, todev,
+			cmd, cmdlen,
+			sense, senselen,
+			data, size
+		);
 
-   /*
-    * No idea what these bytes really mean.  Normally they are always 0's
-    * when things are in a happy state.
-    */
-   if (rsp.zero[0] != 0 ||
-       rsp.zero[1] != 0 ||
-       rsp.zero[2] != 0 ||
-       rsp.zero[3] != 0 ||
-       rsp.zero[4] != 0)
-      {
-        GP_DEBUG( "error: ****  usb_wrap_OK failed" );
-        return GP_ERROR;
-      }
-   return GP_OK;
+	/* Assuming plain USB, emulating SCSI ... */
+
+	memset(&hdr, 0, sizeof(hdr));
+	hdr.magic	= UW_MAGIC_OUT;
+	hdr.tag		= uw_value(ums_tag);
+	ums_tag++;
+	hdr.rw_length	= uw_value(size);
+	hdr.length	= 12; /* seems to be always 12, even as we send 16 byte CDBs */
+	hdr.flags	= todev?0:(1<<7);
+	hdr.lun		= 0;
+
+	memcpy(hdr.cdb, cmd, cmdlen);
+
+	/* WRITE scsi header / cdb */
+	if ((ret=gp_port_write(dev, (char*)&hdr, sizeof(hdr))) < GP_OK) {
+		GP_DEBUG( "scsi_wrap_cmd *** FAILED to write scsi cmd" );
+		return GP_ERROR_IO;
+	}
+	/* WRITE / READ data blob */
+	if (todev) {
+		if ((ret=gp_port_write(dev, (char*)data, size)) < GP_OK) {
+			GP_DEBUG( "scsi_wrap_cmd *** FAILED to write scsi data" );
+			return GP_ERROR_IO;
+		}
+	} else {
+		if ((ret=gp_port_read(dev, (char*)data, size)) < GP_OK) {
+			GP_DEBUG( "scsi_wrap_cmd *** FAILED to read scsi data" );
+			return GP_ERROR_IO;
+		}
+	}
+
+	/* READ RESPONSE */
+	memset(&rsp, 0, sizeof(rsp));
+
+	GP_DEBUG( "usb_wrap_OK" );
+	if ((ret = gp_port_read(dev, (char*)&rsp, sizeof(rsp))) != sizeof(rsp)) {
+		gp_log (GP_LOG_DEBUG, GP_MODULE, "scsi_wrap_cmd *** FAILED (%d vs %d bytes)", (int)sizeof(rsp), ret );
+		if (ret < GP_OK)
+			return ret;
+		return GP_ERROR;
+	}
+	if (	!UW_EQUAL(rsp.magic, UW_MAGIC_IN) ||
+		!UW_EQUAL(rsp.tag, hdr.tag))
+	{
+		GP_DEBUG( "scsi_wrap_cmd wrong session *** FAILED" );
+		return GP_ERROR;
+	}
+	/*
+	 * 32bit residual length (0) and 8 bit status (0) are good.
+	 */
+	if (	rsp.residue.c1 != 0 ||
+		rsp.residue.c2 != 0 ||
+		rsp.residue.c3 != 0 ||
+		rsp.residue.c4 != 0 ||
+		rsp.status != 0) {
+		GP_DEBUG( "Error: scsi_wrap_cmd - residual non-0 or status %x", rsp.status);
+		return GP_ERROR;
+	}
+	return GP_OK;
 }
 
+#define gp_port_send_scsi_cmd scsi_wrap_cmd
+
 static int
 usb_wrap_RDY(gp_port* dev, unsigned int type)
 {
-   uw_header_t hdr;
    uw_pkout_rdy_t msg;
-   int ret, retries = 3;
+   int ret;
+   char sense_buffer[32];
+   uw_scsicmd_t cmd;
 
    GP_DEBUG( "usb_wrap_RDY" );
 
-try_rdy_again:
-   memset(&hdr, 0, sizeof(hdr));
+   memset(&cmd,0,sizeof(cmd));
+   cmd.cmd    		= cmdbyte(type, 0);
+   cmd.length 		= uw_value(sizeof(msg));
+
    memset(&msg, 0, sizeof(msg));
-
-   hdr.magic     = UW_MAGIC_OUT;
-   hdr.sessionid = uw_value(getpid());
-   hdr.rw_length = uw_value(sizeof(msg));
-   hdr.length    = uw_value(sizeof(msg));
-   msg.length    = uw_value(sizeof(msg));
-   MAKE_UW_REQUEST_RDY (&hdr.request_type, type);
-   msg.packet_type = UW_PACKET_RDY;
-  
-   if ((ret=gp_port_write(dev, (char*)&hdr, sizeof(hdr))) < GP_OK ||
-       (ret=gp_port_write(dev, (char*)&msg, sizeof(msg))) < GP_OK)
-   {
+   msg.length    	= uw_value(sizeof(msg));
+   msg.packet_type	= UW_PACKET_RDY;
+   ret = gp_port_send_scsi_cmd (dev, 1, (char*)&cmd, sizeof(cmd),
+   	 sense_buffer, sizeof(sense_buffer), (char*)&msg, sizeof(msg));
+   if (ret<GP_OK)
       GP_DEBUG( "usb_wrap_RDY *** FAILED" );
-      return ret;
-   }
-
-   if ((ret=usb_wrap_OK(dev, &hdr, type)) != GP_OK)
-   {
-      if (!retries--)
-      {
-        GP_DEBUG( "usb_wrap_RDY GIVING UP" );
-        return ret;
-      }
-      GP_DEBUG( "usb_wrap_RDY *** RETRYING" );
-      goto try_rdy_again;
-   }
    return GP_OK;
 }
 
 static int
 usb_wrap_STAT(gp_port* dev, unsigned int type)
 {
-   uw_header_t hdr;
    uw_stat_t msg;
+   uw32_t xlen;
    int ret;
+   char sense_buffer[32];
+   uw_scsicmd_t cmd;
 
    GP_DEBUG( "usb_wrap_STAT" );
 
-   memset(&hdr, 0, sizeof(hdr));
-   memset(&msg, 0, sizeof(msg));
+   memset(&cmd, 0, sizeof(cmd));
+   cmd.cmd    = cmdbyte(type, 3);
+   cmd.length = uw_value(sizeof(msg));
 
-   hdr.magic = UW_MAGIC_OUT;
-   hdr.sessionid = uw_value(getpid());
-   hdr.rw_length = uw_value(sizeof(msg));
-   hdr.length    = uw_value(sizeof(msg));
-   MAKE_UW_REQUEST_STAT (&hdr.request_type, type);
-  
-   if ((ret=gp_port_write(dev, (char*)&hdr, sizeof(hdr))) < GP_OK ||
-       (ret=gp_port_read(dev, (char*)&msg, sizeof(msg))) != sizeof(msg))
+   memset(&msg, 0, sizeof(msg));
+   ret = gp_port_send_scsi_cmd (dev, 0, (char*)&cmd, sizeof(cmd),
+   	 sense_buffer, sizeof(sense_buffer), (char*)&msg, sizeof(msg));
+
+   if (ret < GP_OK)
    {
       GP_DEBUG( "usb_wrap_STAT *** FAILED" );
       if (ret < GP_OK)
@@ -319,12 +349,13 @@ usb_wrap_STAT(gp_port* dev, unsigned int type)
       return GP_ERROR;
    }
 
-   if (!UW_EQUAL(msg.length, hdr.length) || !UW_EQUAL(msg.packet_type, UW_PACKET_STAT))
+   xlen = uw_value(sizeof(msg));
+   if (!UW_EQUAL(msg.length, xlen) || !UW_EQUAL(msg.packet_type, UW_PACKET_STAT))
    {
       GP_DEBUG( "usb_wrap_STAT got bad packet *** FAILED" );
       return GP_ERROR;
    }
-   
+
    if (msg.zero[0] != 0 ||
        msg.zero[1] != 0 ||
        msg.zero[2] != 0 ||
@@ -334,72 +365,71 @@ usb_wrap_STAT(gp_port* dev, unsigned int type)
    {
       GP_DEBUG( "warning: usb_wrap_STAT found non-zero bytes (ignoring)" );
    }
-
-   return usb_wrap_OK(dev, &hdr, type);
+   return GP_OK;
 }
 
 static int
 usb_wrap_CMND(gp_port* dev, unsigned int type, char* sierra_msg, int sierra_len)
 {
-   uw_header_t hdr;
    uw_pkout_sierra_hdr_t* msg;
    int ret, msg_len = sizeof(*msg) + sierra_len;
+   char sense_buffer[32];
+   uw_scsicmd_t cmd;
    
    GP_DEBUG( "usb_wrap_CMND" );
-   
+
+   memset(&cmd,  0, sizeof(cmd));
+   cmd.cmd    = cmdbyte(type, 1);
+   cmd.length = uw_value(msg_len);
+
    msg = (uw_pkout_sierra_hdr_t*)malloc(msg_len);
-   memset(&hdr, 0, sizeof(hdr));
    memset(msg,  0, msg_len);
-   
-   hdr.magic = UW_MAGIC_OUT;
-   hdr.sessionid = uw_value(getpid());
-   hdr.rw_length = uw_value(msg_len);
-   hdr.length    = uw_value(msg_len);
-   msg->length   = uw_value(msg_len);
-   MAKE_UW_REQUEST_CMND (&hdr.request_type, type);
-   msg->packet_type = UW_PACKET_DATA;
+   msg->length 		= uw_value(msg_len);
+   msg->packet_type	= UW_PACKET_DATA;
    memcpy((char*)msg + sizeof(*msg), sierra_msg, sierra_len);
-   GP_DEBUG( "usb_wrap_CMND writing %i + %i",
-                   sizeof(hdr), msg_len);
+
+   GP_DEBUG( "usb_wrap_CMND writing %i", msg_len);
    
-   if ((ret=gp_port_write(dev, (char*)&hdr, sizeof(hdr))) < GP_OK ||
-       (ret=gp_port_write(dev, (char*)msg, msg_len)) < GP_OK)
-   {
-      GP_DEBUG( "usb_wrap_CMND ** WRITE FAILED");
-      free(msg);
-      return ret;
-   }
+   ret = gp_port_send_scsi_cmd (dev, 1, (char*)&cmd, sizeof(cmd),
+   	 sense_buffer, sizeof(sense_buffer), (char*)msg, msg_len);
    free(msg);
 
-   return usb_wrap_OK(dev, &hdr, type);
+   if (ret < GP_OK)
+   {
+      GP_DEBUG( "usb_wrap_CMND ** WRITE FAILED");
+      return ret;
+   }
+   return GP_OK;
 }
 
 static int
 usb_wrap_SIZE(gp_port* dev, unsigned int type, uw32_t* size)
 {
-   uw_header_t hdr;
+   uw32_t xlen;
    uw_size_t msg;
    int ret;
+   char sense_buffer[32];
+   uw_scsicmd_t cmd;
   
    GP_DEBUG( "usb_wrap_SIZE" );
-   memset(&hdr, 0, sizeof(hdr));
-   memset(&msg, 0, sizeof(msg));
 
-   hdr.magic = UW_MAGIC_OUT;
-   hdr.sessionid = uw_value(getpid());
-   hdr.rw_length = uw_value(sizeof(msg));
-   hdr.length    = uw_value(sizeof(msg));
-   MAKE_UW_REQUEST_SIZE (&hdr.request_type, type);
-   if ((ret=gp_port_write(dev, (char*)&hdr, sizeof(hdr))) < GP_OK ||
-       (ret=gp_port_read(dev, (char*)&msg, sizeof(msg))) != sizeof(msg))
+   memset(&cmd,  0, sizeof(cmd));
+   cmd.cmd 	= cmdbyte(type, 4);
+   cmd.length	= uw_value(sizeof(msg));
+
+   memset(&msg, 0, sizeof(msg));
+   ret = gp_port_send_scsi_cmd (dev, 0, (char*)&cmd, sizeof(cmd),
+   	 sense_buffer, sizeof(sense_buffer), (char*)&msg, sizeof(msg));
+
+   if (ret < GP_OK)
    {
       GP_DEBUG( "usb_wrap_SIZE *** FAILED" );
       if (ret < GP_OK)
 	return ret;
       return GP_ERROR;
    }
-
-   if (!UW_EQUAL(msg.length, hdr.length) || !UW_EQUAL(msg.packet_type, UW_PACKET_DATA))
+   xlen = uw_value(sizeof(msg));
+   if (!UW_EQUAL(msg.length, xlen) || !UW_EQUAL(msg.packet_type, UW_PACKET_DATA))
    {
       GP_DEBUG( "usb_wrap_SIZE got bad packet *** FAILED" );
       return GP_ERROR;
@@ -412,19 +442,18 @@ usb_wrap_SIZE(gp_port* dev, unsigned int type, uw32_t* size)
    {
       GP_DEBUG( "warning: usb_wrap_SIZE found non-zero bytes (ignoring)" );
    }
-
    *size = msg.size;
-
-   return usb_wrap_OK(dev, &hdr, type);
+   return GP_OK;
 }
 
 static int
 usb_wrap_DATA (GPPort *dev, unsigned int type, char *sierra_response, int *sierra_len, uw32_t size)
 {
-   uw_header_t hdr;
    uw_pkout_sierra_hdr_t* msg;
    unsigned int msg_len;
    int ret;
+   char sense_buffer[32];
+   uw_scsicmd_t cmd;
 
    GP_DEBUG( "usb_wrap_DATA" );
 
@@ -441,29 +470,24 @@ usb_wrap_DATA (GPPort *dev, unsigned int type, char *sierra_response, int *sierr
    }
    *sierra_len = msg_len - sizeof(*msg);
 
-   msg = (uw_pkout_sierra_hdr_t*)malloc(msg_len);
-   memset(msg, 0, sizeof(msg));
-   memset(&hdr, 0, sizeof(hdr));
+   msg = (uw_pkout_sierra_hdr_t*)calloc(msg_len,1);
 
-   hdr.magic = UW_MAGIC_OUT;
-   hdr.sessionid = uw_value(getpid());
-   hdr.rw_length = uw_value(msg_len);
-   hdr.length    = uw_value(msg_len);
-   MAKE_UW_REQUEST_DATA (&hdr.request_type, type);
+   memset(&cmd, 0, sizeof(cmd));
+   cmd.cmd 	= cmdbyte(type, 2);
+   cmd.length	= uw_value(msg_len);
 
-   if ((ret=gp_port_write(dev, (char*)&hdr, sizeof(hdr))) < GP_OK ||
-       (ret=gp_port_read(dev, (char*)msg, msg_len)) != msg_len)
+   ret = gp_port_send_scsi_cmd (dev, 0, (char*)&cmd, sizeof(cmd),
+   	 sense_buffer, sizeof(sense_buffer), (char*)msg, msg_len);
+
+   if (ret < GP_OK)
    {
       GP_DEBUG( "usb_wrap_DATA FAILED" );
       free(msg);
-      if (ret < GP_OK)
-	return ret;
-      return GP_ERROR;
+      return ret;
    }
    memcpy(sierra_response, (char*)msg + sizeof(*msg), *sierra_len);
    free(msg);
-
-   return usb_wrap_OK(dev, &hdr, type);
+   return GP_OK;
 }
 
 /*
@@ -497,4 +521,3 @@ usb_wrap_read_packet (GPPort *dev, unsigned int type, char *sierra_response, int
 	
 	return sierra_len;
 }
-
