@@ -1,6 +1,6 @@
 /* sierra.c:
  *
- * Copyright  2001 Lutz Mller <lutz@users.sourceforge.net>
+ * Copyright 2001 Lutz Mueller <lutz@users.sourceforge.net>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -14,9 +14,11 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
+#define _BSD_SOURCE
+
 #include "config.h"
 #include "sierra.h"
 
@@ -80,7 +82,8 @@ static struct {
 		SIERRA_NO_51 | SIERRA_LOW_SPEED, NULL },
 	{"Agfa", "ePhoto 1280",	SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
 	{"Agfa", "ePhoto 1680", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
-	{"Apple", "QuickTake 200", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
+	/* unclear, if driven by fuji driver or by sierra driver */
+	{"Apple", "QuickTake 200 (Sierra Mode)", SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
 	{"Chinon", "ES-1000", 	SIERRA_MODEL_DEFAULT,	0, 0, 0, NULL },
 	{"Epson", "PhotoPC 500", SIERRA_MODEL_EPSON,	0, 0, 0, NULL },
 	{"Epson", "PhotoPC 550", SIERRA_MODEL_EPSON,	0, 0, 0, NULL },
@@ -276,9 +279,12 @@ int camera_abilities (CameraAbilitiesList *list)
 		a.port     = GP_PORT_SERIAL;
 		if ((sierra_cameras[x].usb_vendor  > 0) &&
 		    (sierra_cameras[x].usb_product > 0)) {
+#ifdef linux
+			/* The USB SCSI generic passthrough driver only works on Linux currently */
 			if (sierra_cameras[x].flags & (SIERRA_WRAP_USB_OLYMPUS|SIERRA_WRAP_USB_PENTAX|SIERRA_WRAP_USB_NIKON))
 			    a.port |= GP_PORT_USB_SCSI;
                         else
+#endif
 			    a.port |= GP_PORT_USB;
 		}
 		a.speed[0] = 9600;
@@ -531,8 +537,9 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	char *jpeg_data = NULL;
 	int jpeg_size;
 	const char *data, *mime_type;
-	long int size;
-	int download_size, audio_info[8], transferred;
+	long unsigned int size;
+	int download_size, audio_info[8];
+	unsigned int transferred;
 
 	/*
 	 * Get the file number from the CameraFileSystem.
@@ -574,14 +581,14 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 	switch (type) {
 	case GP_FILE_TYPE_PREVIEW:
 	case GP_FILE_TYPE_EXIF:
-		sierra_get_size(camera, 13, n, &download_size, context);
+		CHECK_STOP (camera, sierra_get_size(camera, 13, n, &download_size, context));
 		break;
 	case GP_FILE_TYPE_NORMAL:
-		sierra_get_size(camera, 12, n, &download_size, context);
+		CHECK_STOP (camera, sierra_get_size(camera, 12, n, &download_size, context));
 		break;
 	case GP_FILE_TYPE_AUDIO:
-		sierra_get_string_register (camera, 43, n, NULL,
-			(unsigned char *) &audio_info, &transferred, context);
+		CHECK_STOP (camera, sierra_get_string_register (camera, 43, n, NULL,
+			(unsigned char *) &audio_info, &transferred, context));
 		if (transferred == 0) 
 			download_size = 0;
 		else
@@ -593,7 +600,7 @@ get_file_func (CameraFilesystem *fs, const char *folder, const char *filename,
 
 	/* Get the file */
 	CHECK_STOP (camera, sierra_get_string_register (camera, regd, n,
-					file, NULL, &download_size,  context));
+					file, NULL, (unsigned int *)&download_size,  context));
 	if (download_size == 0) {
 		/*
 		 * Assume a failure. At least coolpix 880 returns no error
@@ -746,7 +753,7 @@ put_file_func (CameraFilesystem * fs, const char *folder, const char *filename,
 	char *picture_folder;
 	int ret;
 	const char *data_file;
-	long data_size;
+	long unsigned int data_size;
 	int available_memory;
 
 	GP_DEBUG ("*** put_file_func");
@@ -1936,15 +1943,20 @@ camera_summary (Camera *camera, CameraText *summary, GPContext *c)
 	}
 	/* Get all the string-related info */
 
-	if (sierra_get_string_register (camera, 27, 0, NULL, t, &v, c) >= 0)
+	if (sierra_get_string_register (camera, 27, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0)
 		sprintf (buf+strlen(buf), _("Camera Model: %s\n"), t);
-	if (sierra_get_string_register (camera, 48, 0, NULL, t, &v, c) >= 0)
+	if (sierra_get_string_register (camera, 48, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0)
 		sprintf (buf+strlen(buf), _("Manufacturer: %s\n"), t);
-	if (sierra_get_string_register (camera, 22, 0, NULL, t, &v, c) >= 0)
+	if (sierra_get_string_register (camera, 22, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0)
 		sprintf (buf+strlen(buf), _("Camera ID: %s\n"), t);
-	if (sierra_get_string_register (camera, 25, 0, NULL, t, &v, c) >= 0)
+	if (sierra_get_string_register (camera, 25, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0)
 		sprintf (buf+strlen(buf), _("Serial Number: %s\n"), t);
-	if (sierra_get_string_register (camera, 26, 0, NULL, t, &v, c) >= 0)
+	if (sierra_get_string_register (camera, 26, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0)
 		sprintf (buf+strlen(buf), _("Software Rev.: %s\n"), t);
 
 	/* Get all the integer information */
@@ -2001,7 +2013,8 @@ storage_info_func (CameraFilesystem *fs,
 	sif->fields |= GP_STORAGEINFO_FILESYSTEMTYPE;
 	sif->fstype  = GP_STORAGEINFO_FST_DCF;
 
-	if (sierra_get_string_register (camera, 25, 0, NULL, t, &v, c) >= 0) {
+	if (sierra_get_string_register (camera, 25, 0, NULL,
+					(unsigned char *)t, (unsigned int *)&v, c) >= 0) {
 		sif->fields |= GP_STORAGEINFO_LABEL;
 		strcpy (sif->label, t);
 	}
@@ -2279,6 +2292,10 @@ camera_init (Camera *camera, GPContext *context)
         /* FIXME??? What's that for? "Resetting folder system"? */
 	sierra_set_int_register (camera, 83, -1, NULL);
 #endif
+	/* How to switch the coolpix 2500 between RAW / NORMAL
+   return dsc->SetStr(0x16, raw_enabled ? "DIAG RAW" : "NIKON DIGITAL CAMERA" );
+        ret = sierra_set_string_register (camera, 0x16, "NIKON DIGITAL CAMERA", strlen("NIKON DIGITAL CAMERA"), NULL);
+	 */
 
         /* Folder support? */
 	CHECK_STOP_FREE (camera, gp_port_set_timeout (camera->port, 50));
