@@ -16,11 +16,12 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with puppy; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  along with puppy; if not, write to the 
+  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA  02110-1301  USA
 
 */
-
+#define _BSD_SOURCE
 
 #include "config.h"
 
@@ -52,12 +53,13 @@
 #include <utime.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/ioctl.h>
 #include <unistd.h>
 #include <fcntl.h>
 
-#include <iconv.h>
-#include <langinfo.h>
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
+# include <iconv.h>
+# include <langinfo.h>
+#endif
 
 #include "usb_io.h"
 #include "tf_bytes.h"
@@ -65,9 +67,13 @@
 #define PUT 0
 #define GET 1
 
+#if 0
 static int quiet = 0;
+#endif
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 static iconv_t cd_locale_to_latin1;
 static iconv_t cd_latin1_to_locale;
+#endif
 
 struct _mapnames {
 	char *tfname;
@@ -86,6 +92,7 @@ backslash(char *path) {
 		*s='\\';
 }
 
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 static char*
 strdup_to_latin1 (const char *str) {
 	size_t	ret, srclen, dstlen, ndstlen;
@@ -137,7 +144,7 @@ strdup_to_locale (char *str) {
 		if (ret == -1) {
 			perror("iconv");
 			free (dest);
-			dest = NULL;
+			return NULL;
 		}
 		break;
 	}
@@ -150,6 +157,10 @@ strdup_to_locale (char *str) {
 	}
 	return dest;
 }
+#else
+# define strdup_to_latin1 strdup
+# define strdup_to_locale strdup
+#endif
 
 static char*
 _convert_and_logname(Camera *camera, char *tfname) {
@@ -278,6 +289,7 @@ do_cmd_turbo(Camera *camera, char *state, GPContext *context)
 	return GP_ERROR_IO;
 }
 
+#if 0
 static int
 do_cmd_reset(Camera *camera, GPContext *context)
 {
@@ -308,6 +320,7 @@ do_cmd_reset(Camera *camera, GPContext *context)
 	}
 	return GP_ERROR_IO;
 }
+#endif
 
 static int
 do_cmd_ready(Camera *camera, GPContext *context)
@@ -340,6 +353,7 @@ do_cmd_ready(Camera *camera, GPContext *context)
 	return GP_OK;
 }
 
+#if 0
 static int
 do_cancel(Camera *camera, GPContext *context)
 {
@@ -370,7 +384,7 @@ do_cancel(Camera *camera, GPContext *context)
 	}
 	return GP_ERROR_IO;
 }
-
+#endif
 
 static void
 decode_dir(Camera *camera, struct tf_packet *p, int listdirs, CameraList *list)
@@ -459,6 +473,7 @@ decode_and_get_info(Camera *camera, const char *folder, struct tf_packet *p, con
     }
 }
 
+#if 0
 static int
 do_hdd_rename(Camera *camera, char *srcPath, char *dstPath, GPContext *context)
 {
@@ -524,7 +539,7 @@ static void finalStats(uint64_t bytes, time_t startTime)
                 ((bytes * 8.0) / delta) / (1000.0 * 1000.0));
     }
 }
-
+#endif
 
 static int
 camera_config_get (Camera *camera, CameraWidget **window, GPContext *context) 
@@ -1184,8 +1199,10 @@ CameraFilesystemFuncs fsfuncs = {
 static int
 camera_exit (Camera *camera, GPContext *context)
 {
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 	iconv_close (cd_latin1_to_locale);
 	iconv_close (cd_locale_to_latin1);
+#endif
 	free (camera->pl->names);
 	free (camera->pl);
 	return GP_OK;
@@ -1211,12 +1228,14 @@ camera_init (Camera *camera, GPContext *context)
 	camera->pl = calloc (sizeof (CameraPrivateLibrary),1);
 	if (!camera->pl) return GP_ERROR_NO_MEMORY;
 
+#if defined(HAVE_ICONV) && defined(HAVE_LANGINFO_H)
 	curloc = nl_langinfo (CODESET);
 	if (!curloc) curloc="UTF-8";
 	cd_latin1_to_locale = iconv_open(curloc, "iso-8859-1");
 	if (!cd_latin1_to_locale) return GP_ERROR_NO_MEMORY;
 	cd_locale_to_latin1 = iconv_open("iso-8859-1", curloc);
 	if (!cd_locale_to_latin1) return GP_ERROR_NO_MEMORY;
+#endif
 
 	do_cmd_ready (camera, context);
 	return GP_OK;
