@@ -313,6 +313,7 @@ gp_port_library_list (GPPortInfoList *list)
 		gp_port_info_set_path (info, "usb:");
 		C_GP (gp_port_info_list_append (list, info));
 	}
+	libusb_free_device_list (devs, 1);
 	libusb_exit (ctx); /* should free all stuff above */
 	free (descs);
 	return (GP_OK);
@@ -341,6 +342,8 @@ gp_port_usb_exit (GPPort *port)
 {
 	if (port->pl) {
 		free (port->pl->descs);
+		if (port->pl->nrofdevs)
+			libusb_free_device_list (port->pl->devs, 1);
 		libusb_exit (port->pl->ctx);
 		free (port->pl);
 		port->pl = NULL;
@@ -1026,7 +1029,7 @@ gp_port_usb_match_mtp_device(struct libusb_device *dev,int *configno, int *inter
 	}
 	/* get string descriptor at 0xEE */
 	ret = usb_get_descriptor (devh, 0x03, 0xee, buf, sizeof(buf));
-	if (ret > 0) gp_log_data("get_MS_OSD",buf, ret);
+	if (ret > 0) GP_LOG_DATA (buf, ret, "get_MS_OSD");
 	if (ret < 10) goto errout;
 	if (!((buf[2] == 'M') && (buf[4]=='S') && (buf[6]=='F') && (buf[8]=='T')))
 		goto errout;
@@ -1040,7 +1043,7 @@ gp_port_usb_match_mtp_device(struct libusb_device *dev,int *configno, int *inter
 		GP_LOG_E ("ret is %d, buf[0] is %x\n", ret, buf[0]);
 		goto errout;
 	}
-	if (ret > 0) gp_log_data("get_MS_ExtDesc",buf, ret);
+	if (ret > 0) GP_LOG_DATA (buf, ret, "get_MS_ExtDesc");
 	if ((buf[0x12] != 'M') || (buf[0x13] != 'T') || (buf[0x14] != 'P')) {
 		GP_LOG_E ("buf at 0x12 is %02x%02x%02x\n", buf[0x12], buf[0x13], buf[0x14]);
 		goto errout;
@@ -1051,7 +1054,7 @@ gp_port_usb_match_mtp_device(struct libusb_device *dev,int *configno, int *inter
 		GP_LOG_E ("ret is %d, buf[0] is %x\n", ret, buf[0]);
 		goto errout;
 	}
-	if (ret > 0) gp_log_data("get_MS_ExtProp",buf, ret);
+	if (ret > 0) GP_LOG_DATA (buf, ret, "get_MS_ExtProp");
 	if ((buf[0x12] != 'M') || (buf[0x13] != 'T') || (buf[0x14] != 'P')) {
 		GP_LOG_E ("buf at 0x12 is %02x%02x%02x\n", buf[0x12], buf[0x13], buf[0x14]);
 		goto errout;
