@@ -13,8 +13,9 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * along with this program; if not, write to the
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA  02110-1301  USA
  */
 #define _BSD_SOURCE
 
@@ -86,8 +87,7 @@ gp_port_usbdiskdirect_lock (GPPort *port, const char *path)
 #ifdef HAVE_LOCKDEV
 	int pid;
 
-	gp_log (GP_LOG_DEBUG, "gphoto2-port-usbdiskdirect",
-		"Trying to lock '%s'...", path);
+	GP_LOG_D ("Trying to lock '%s'...", path);
 
 	pid = dev_lock (path);
 	if (pid) {
@@ -207,6 +207,7 @@ gp_port_library_list (GPPortInfoList *list)
 	DIR *dir;
 	struct dirent *dirent;
 	GPPortInfo info;
+	int ret;
 	unsigned short vendor_id, product_id;
 
 	dir = opendir ("/sys/block");
@@ -232,7 +233,9 @@ gp_port_library_list (GPPortInfoList *list)
 			  dirent->d_name);
 		gp_port_info_set_path (info, path);
 		gp_port_info_set_name (info, _("USB Mass Storage direct IO"));
-		CHECK (gp_port_info_list_append (list, info))
+		ret = gp_port_info_list_append (list, info);
+		if (ret < GP_OK)
+			break;
 	}
 	closedir (dir);
 	return GP_OK;
@@ -241,9 +244,7 @@ gp_port_library_list (GPPortInfoList *list)
 static int
 gp_port_usbdiskdirect_init (GPPort *port)
 {
-	port->pl = calloc (1, sizeof (GPPortPrivateLibrary));
-	if (!port->pl)
-		return GP_ERROR_NO_MEMORY;
+	C_MEM (port->pl = calloc (1, sizeof (GPPortPrivateLibrary)));
 
 	port->pl->fd = -1;
 
@@ -253,13 +254,10 @@ gp_port_usbdiskdirect_init (GPPort *port)
 static int
 gp_port_usbdiskdirect_exit (GPPort *port)
 {
-	if (!port)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port);
 
-	if (port->pl) {
-		free (port->pl);
-		port->pl = NULL;
-	}
+	free (port->pl);
+	port->pl = NULL;
 
 	return GP_OK;
 }
@@ -277,8 +275,7 @@ gp_port_usbdiskdirect_open (GPPort *port)
 			result = gp_port_usbdiskdirect_lock (port, path);
 			if (result == GP_OK)
 				break;
-			gp_log (GP_LOG_DEBUG, "gphoto2-port-usbdiskdirect",
-				"Failed to get a lock, trying again...");
+			GP_LOG_D ("Failed to get a lock, trying again...");
 			sleep (1);
 		}
 		CHECK (result)
@@ -316,8 +313,7 @@ static int gp_port_usbdiskdirect_seek (GPPort *port, int offset, int whence)
 {
 	off_t ret;
 
-	if (!port)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (!port);
 
 	/* The device needs to be opened for that operation */
 	if (port->pl->fd == -1)
@@ -339,8 +335,7 @@ gp_port_usbdiskdirect_write (GPPort *port, const char *bytes, int size)
 {
 	int ret;
 
-	if (!port)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port);
 
 	/* The device needs to be opened for that operation */
 	if (port->pl->fd == -1)
@@ -361,8 +356,7 @@ gp_port_usbdiskdirect_read (GPPort *port, char *bytes, int size)
 {
 	int ret;
 
-	if (!port)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port);
 
 	/* The device needs to be opened for that operation */
 	if (port->pl->fd == -1)
@@ -381,8 +375,7 @@ gp_port_usbdiskdirect_read (GPPort *port, char *bytes, int size)
 static int
 gp_port_usbdiskdirect_update (GPPort *port)
 {
-	if (!port)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port);
 
 	memcpy (&port->settings, &port->settings_pending,
 		sizeof (port->settings));
@@ -396,12 +389,10 @@ gp_port_usbdiskdirect_find_device(GPPort *port, int idvendor, int idproduct)
 	unsigned short vendor_id, product_id;
 	const char *disk;
 
-	if (!port)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (port);
 
 	disk = strrchr (port->settings.usbdiskdirect.path, '/');
-	if (!disk)
-		return GP_ERROR_BAD_PARAMETERS;
+	C_PARAMS (disk);
 	disk++;
 
 	CHECK (gp_port_usbdiskdirect_get_usb_id (disk,
@@ -417,10 +408,9 @@ gp_port_library_operations ()
 {
 	GPPortOperations *ops;
 
-	ops = malloc (sizeof (GPPortOperations));
+	ops = calloc (1, sizeof (GPPortOperations));
 	if (!ops)
 		return (NULL);
-	memset (ops, 0, sizeof (GPPortOperations)); 
 
 	ops->init   = gp_port_usbdiskdirect_init;
 	ops->exit   = gp_port_usbdiskdirect_exit;
