@@ -14,27 +14,26 @@ var NAVTREEINDEX3 =
 "gphoto2-port-library_8h.html#af4a2e56a43c90ed9d4766c9ba6919cc1":[2,0,3,0,1,6],
 "gphoto2-port-library_8h_source.html":[2,0,3,0,1],
 "gphoto2-port-log_8c.html":[2,0,3,1,2],
-"gphoto2-port-log_8c.html#a07601ec204167a55885e02b80edd3fcf":[2,0,3,1,2,17],
-"gphoto2-port-log_8c.html#a0b14529482e5bc725bcc003583337ea7":[2,0,3,1,2,15],
-"gphoto2-port-log_8c.html#a1f87fb4d74a1713ca959ebee544ba860":[2,0,3,1,2,14],
+"gphoto2-port-log_8c.html#a07601ec204167a55885e02b80edd3fcf":[2,0,3,1,2,16],
+"gphoto2-port-log_8c.html#a0b14529482e5bc725bcc003583337ea7":[2,0,3,1,2,14],
 "gphoto2-port-log_8c.html#a25d3dff9fc4f2a43d2fb7c992d46e24b":[2,0,3,1,2,4],
 "gphoto2-port-log_8c.html#a2bdf0f15991734c7a632c10714553277":[2,0,3,1,2,5],
 "gphoto2-port-log_8c.html#a32a3cf3d9dd914f5aeeca5423c157934":[2,0,3,1,2,1],
-"gphoto2-port-log_8c.html#a3b5dcab5cde5c5c3e39255d892765fc1":[2,0,3,1,2,11],
 "gphoto2-port-log_8c.html#a425183fc022968cf26219b38421b42ee":[2,0,3,1,2,9],
 "gphoto2-port-log_8c.html#a4d62d7864045598068173b20f87380ea":[2,0,3,1,2,6],
+"gphoto2-port-log_8c.html#a5e9bad704f3b065a2d5b653c7516a1ee":[2,0,3,1,2,17],
 "gphoto2-port-log_8c.html#a75278405e7f034d2b1af80bfd94675fe":[2,0,3,1,2,10],
-"gphoto2-port-log_8c.html#a77325969d9eb7e1b9c2285233c7b3862":[2,0,3,1,2,12],
+"gphoto2-port-log_8c.html#a77325969d9eb7e1b9c2285233c7b3862":[2,0,3,1,2,11],
 "gphoto2-port-log_8c.html#aa670fefafc10fc80dba398d2050ce62c":[2,0,3,1,2,3],
-"gphoto2-port-log_8c.html#aad08200a2e1b98c54ba32e8c80bfac6c":[2,0,3,1,2,13],
-"gphoto2-port-log_8c.html#ac724677ed0dfe9431fac69c30e2cb39b":[2,0,3,1,2,16],
+"gphoto2-port-log_8c.html#aad08200a2e1b98c54ba32e8c80bfac6c":[2,0,3,1,2,12],
+"gphoto2-port-log_8c.html#ac724677ed0dfe9431fac69c30e2cb39b":[2,0,3,1,2,15],
+"gphoto2-port-log_8c.html#acb3fc0f7a49dd49fa8bdbe4cdaacdd0a":[2,0,3,1,2,13],
 "gphoto2-port-log_8c.html#accc780c98fc95b8ddce8f259c1575745":[2,0,3,1,2,7],
 "gphoto2-port-log_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73":[2,0,3,1,2,2],
 "gphoto2-port-log_8c.html#ae21578f6dac5be34d83475a83e271d73":[2,0,3,1,2,8],
 "gphoto2-port-log_8h.html":[2,0,3,0,2],
 "gphoto2-port-log_8h.html#a07601ec204167a55885e02b80edd3fcf":[2,0,3,0,2,8],
 "gphoto2-port-log_8h.html#a0b14529482e5bc725bcc003583337ea7":[2,0,3,0,2,6],
-"gphoto2-port-log_8h.html#a1f87fb4d74a1713ca959ebee544ba860":[2,0,3,0,2,5],
 "gphoto2-port-log_8h.html#a77325969d9eb7e1b9c2285233c7b3862":[2,0,3,0,2,3],
 "gphoto2-port-log_8h.html#a94751f687dece0c1c7a145287c1b5581":[2,0,3,0,2,1],
 "gphoto2-port-log_8h.html#aad08200a2e1b98c54ba32e8c80bfac6c":[2,0,3,0,2,4],
@@ -45,6 +44,7 @@ var NAVTREEINDEX3 =
 "gphoto2-port-log_8h.html#abd2f5081afa2596ee01a61415fcdb06bab7502e71c4972bf803722a33b99be75f":[2,0,3,0,2,2,3],
 "gphoto2-port-log_8h.html#abd2f5081afa2596ee01a61415fcdb06badfd0d1ea537692a3dd8acc3b5675c9d2":[2,0,3,0,2,2,2],
 "gphoto2-port-log_8h.html#ac724677ed0dfe9431fac69c30e2cb39b":[2,0,3,0,2,7],
+"gphoto2-port-log_8h.html#acb3fc0f7a49dd49fa8bdbe4cdaacdd0a":[2,0,3,0,2,5],
 "gphoto2-port-log_8h_source.html":[2,0,3,0,2],
 "gphoto2-port-portability_8c.html":[2,0,3,1,3],
 "gphoto2-port-portability_8c.html#a523999a1e3fa0730e1d8b42d25dab59a":[2,0,3,1,3,3],
@@ -100,56 +100,57 @@ var NAVTREEINDEX3 =
 "gphoto2-port-version_8h.html#a2b1839ee3cf2ec655565825241206719a6138e6df0cd17c5cb782279d11b4bc1c":[2,0,3,0,5,1,0],
 "gphoto2-port-version_8h_source.html":[2,0,3,0,5],
 "gphoto2-port_8c.html":[2,0,3,1,6],
-"gphoto2-port_8c.html#a0077bb0c6918d27e5a36f27087e2c277":[2,0,3,1,6,9],
-"gphoto2-port_8c.html#a08cc8e20df73217baeafccbc71ba9897":[2,0,3,1,6,44],
-"gphoto2-port_8c.html#a0cbdaa571a0eef7441fee91a244e21f2":[2,0,3,1,6,38],
-"gphoto2-port_8c.html#a0d9ec033ed72d9fb9e29bfd8d4010c44":[2,0,3,1,6,22],
+"gphoto2-port_8c.html#a0077bb0c6918d27e5a36f27087e2c277":[2,0,3,1,6,10],
+"gphoto2-port_8c.html#a08cc8e20df73217baeafccbc71ba9897":[2,0,3,1,6,45],
+"gphoto2-port_8c.html#a0cbdaa571a0eef7441fee91a244e21f2":[2,0,3,1,6,39],
+"gphoto2-port_8c.html#a0d9ec033ed72d9fb9e29bfd8d4010c44":[2,0,3,1,6,23],
 "gphoto2-port_8c.html#a1061828e4e2cafb14086ac2bed47f80d":[2,0,3,1,6,4],
-"gphoto2-port_8c.html#a1118c50abbdf1926d6e08e0b6bb1209d":[2,0,3,1,6,43],
-"gphoto2-port_8c.html#a1f8fdfff0fbbc9c9b3b0cc3d22d8c9ca":[2,0,3,1,6,46],
-"gphoto2-port_8c.html#a247bb45fcf90021f45ae137df40dd47a":[2,0,3,1,6,15],
-"gphoto2-port_8c.html#a283ebf127e608cc77b137103bbde3caf":[2,0,3,1,6,39],
-"gphoto2-port_8c.html#a2ae81836b1bca7ae97695d754cc9a3a6":[2,0,3,1,6,18],
-"gphoto2-port_8c.html#a2e5d3e6f918acb16e8ee6996018507a6":[2,0,3,1,6,42],
-"gphoto2-port_8c.html#a3011b7cb854d99053a2d68ff760179b4":[2,0,3,1,6,8],
+"gphoto2-port_8c.html#a1118c50abbdf1926d6e08e0b6bb1209d":[2,0,3,1,6,44],
+"gphoto2-port_8c.html#a1f8fdfff0fbbc9c9b3b0cc3d22d8c9ca":[2,0,3,1,6,47],
+"gphoto2-port_8c.html#a247bb45fcf90021f45ae137df40dd47a":[2,0,3,1,6,16],
+"gphoto2-port_8c.html#a283ebf127e608cc77b137103bbde3caf":[2,0,3,1,6,40],
+"gphoto2-port_8c.html#a2ae81836b1bca7ae97695d754cc9a3a6":[2,0,3,1,6,19],
+"gphoto2-port_8c.html#a2e5d3e6f918acb16e8ee6996018507a6":[2,0,3,1,6,43],
+"gphoto2-port_8c.html#a3011b7cb854d99053a2d68ff760179b4":[2,0,3,1,6,9],
 "gphoto2-port_8c.html#a32a3cf3d9dd914f5aeeca5423c157934":[2,0,3,1,6,1],
-"gphoto2-port_8c.html#a4389daae7f57c7759775ad1dd512c70a":[2,0,3,1,6,32],
-"gphoto2-port_8c.html#a4a192eaac78b326ebe41e8e4441a38e4":[2,0,3,1,6,27],
-"gphoto2-port_8c.html#a4fbc4a2c1583e25d5e220b757375f305":[2,0,3,1,6,41],
-"gphoto2-port_8c.html#a56b83abbf58d7b01bdfd568bc3fff917":[2,0,3,1,6,25],
-"gphoto2-port_8c.html#a5d67338933ddaed39c4fb20a23d76ec2":[2,0,3,1,6,37],
-"gphoto2-port_8c.html#a68344fa88cf4e86b5079fd69a5c22d57":[2,0,3,1,6,45],
-"gphoto2-port_8c.html#a68fb24a4f729ec5be85f4aedf3bb8e4f":[2,0,3,1,6,30],
-"gphoto2-port_8c.html#a75278405e7f034d2b1af80bfd94675fe":[2,0,3,1,6,7],
-"gphoto2-port_8c.html#a78fda26011604ff372d9a1a7ff83bc62":[2,0,3,1,6,16],
-"gphoto2-port_8c.html#a790fff9ba13a8b2730cdc1213ec98d48":[2,0,3,1,6,36],
-"gphoto2-port_8c.html#a7a8d75aa016e04b9c0d3b7849681ebe5":[2,0,3,1,6,19],
+"gphoto2-port_8c.html#a4389daae7f57c7759775ad1dd512c70a":[2,0,3,1,6,33],
+"gphoto2-port_8c.html#a4a192eaac78b326ebe41e8e4441a38e4":[2,0,3,1,6,28],
+"gphoto2-port_8c.html#a4fbc4a2c1583e25d5e220b757375f305":[2,0,3,1,6,42],
+"gphoto2-port_8c.html#a56b83abbf58d7b01bdfd568bc3fff917":[2,0,3,1,6,26],
+"gphoto2-port_8c.html#a5d67338933ddaed39c4fb20a23d76ec2":[2,0,3,1,6,38],
+"gphoto2-port_8c.html#a68344fa88cf4e86b5079fd69a5c22d57":[2,0,3,1,6,46],
+"gphoto2-port_8c.html#a68fb24a4f729ec5be85f4aedf3bb8e4f":[2,0,3,1,6,31],
+"gphoto2-port_8c.html#a75278405e7f034d2b1af80bfd94675fe":[2,0,3,1,6,8],
+"gphoto2-port_8c.html#a78fda26011604ff372d9a1a7ff83bc62":[2,0,3,1,6,17],
+"gphoto2-port_8c.html#a790fff9ba13a8b2730cdc1213ec98d48":[2,0,3,1,6,37],
+"gphoto2-port_8c.html#a7a8d75aa016e04b9c0d3b7849681ebe5":[2,0,3,1,6,20],
 "gphoto2-port_8c.html#a7d1b679bf0152efa60a3d848fb53486a":[2,0,3,1,6,5],
 "gphoto2-port_8c.html#a7dd9e079511891ec9996ebb25c0e6814":[2,0,3,1,6,3],
-"gphoto2-port_8c.html#a8f66d05b6a22677ef689180eacb2f85d":[2,0,3,1,6,21],
-"gphoto2-port_8c.html#a926276a279193a52013da9e05399ec29":[2,0,3,1,6,31],
-"gphoto2-port_8c.html#a946715a386d9280d71b4ec58488aabd4":[2,0,3,1,6,40],
-"gphoto2-port_8c.html#a9503a6f8c4d87a2c22b802ce099cf8ef":[2,0,3,1,6,29],
-"gphoto2-port_8c.html#a976f2b7d7c2bd3f5399a6f5829044957":[2,0,3,1,6,20],
-"gphoto2-port_8c.html#a99a4671624d0b4d5f86cb5aaf94941fb":[2,0,3,1,6,26],
-"gphoto2-port_8c.html#a99a72d6df60bfb165ff9a8d2f1ce239e":[2,0,3,1,6,50],
-"gphoto2-port_8c.html#a9e38b6166cea9b54c8b7637cac740828":[2,0,3,1,6,14],
-"gphoto2-port_8c.html#aa3ac8ac353d96106575bf951f997276c":[2,0,3,1,6,10],
-"gphoto2-port_8c.html#aa5c3be2ad2546c829dc21d4d8fabb08d":[2,0,3,1,6,24],
-"gphoto2-port_8c.html#aa6787fc6eb732987040b1f378489db54":[2,0,3,1,6,49],
+"gphoto2-port_8c.html#a828c4f99cd2fcdbf9b83793b1c7e7ccb":[2,0,3,1,6,7],
+"gphoto2-port_8c.html#a8f66d05b6a22677ef689180eacb2f85d":[2,0,3,1,6,22],
+"gphoto2-port_8c.html#a926276a279193a52013da9e05399ec29":[2,0,3,1,6,32],
+"gphoto2-port_8c.html#a946715a386d9280d71b4ec58488aabd4":[2,0,3,1,6,41],
+"gphoto2-port_8c.html#a9503a6f8c4d87a2c22b802ce099cf8ef":[2,0,3,1,6,30],
+"gphoto2-port_8c.html#a976f2b7d7c2bd3f5399a6f5829044957":[2,0,3,1,6,21],
+"gphoto2-port_8c.html#a99a4671624d0b4d5f86cb5aaf94941fb":[2,0,3,1,6,27],
+"gphoto2-port_8c.html#a99a72d6df60bfb165ff9a8d2f1ce239e":[2,0,3,1,6,51],
+"gphoto2-port_8c.html#a9e38b6166cea9b54c8b7637cac740828":[2,0,3,1,6,15],
+"gphoto2-port_8c.html#aa3ac8ac353d96106575bf951f997276c":[2,0,3,1,6,11],
+"gphoto2-port_8c.html#aa5c3be2ad2546c829dc21d4d8fabb08d":[2,0,3,1,6,25],
+"gphoto2-port_8c.html#aa6787fc6eb732987040b1f378489db54":[2,0,3,1,6,50],
 "gphoto2-port_8c.html#aa9c4fe1daa7b51d494052db913975525":[2,0,3,1,6,6],
-"gphoto2-port_8c.html#aa9dffcdab4b918d2dc2b7d6015c63fb0":[2,0,3,1,6,17],
-"gphoto2-port_8c.html#ab1274205cd3baa2905d0edd78429bcb5":[2,0,3,1,6,13],
-"gphoto2-port_8c.html#ac474f719cd32a6dec42eef980f20f71e":[2,0,3,1,6,11],
-"gphoto2-port_8c.html#ac55c6bd131ac7ab047d8867c853b1bda":[2,0,3,1,6,23],
-"gphoto2-port_8c.html#ac85bf5c84f52b34a8ef9c1d71de2ff5d":[2,0,3,1,6,12],
+"gphoto2-port_8c.html#aa9dffcdab4b918d2dc2b7d6015c63fb0":[2,0,3,1,6,18],
+"gphoto2-port_8c.html#ab1274205cd3baa2905d0edd78429bcb5":[2,0,3,1,6,14],
+"gphoto2-port_8c.html#ac474f719cd32a6dec42eef980f20f71e":[2,0,3,1,6,12],
+"gphoto2-port_8c.html#ac55c6bd131ac7ab047d8867c853b1bda":[2,0,3,1,6,24],
+"gphoto2-port_8c.html#ac85bf5c84f52b34a8ef9c1d71de2ff5d":[2,0,3,1,6,13],
 "gphoto2-port_8c.html#ad3d8a3bd0c0b677acef144f2c2ef6d73":[2,0,3,1,6,2],
-"gphoto2-port_8c.html#addd41ab8b46062ec99cf07cafc12319d":[2,0,3,1,6,33],
-"gphoto2-port_8c.html#ae732282e180518c78a5854c023e20620":[2,0,3,1,6,34],
-"gphoto2-port_8c.html#af3b9610f316d951aa2a99b225dba748a":[2,0,3,1,6,48],
-"gphoto2-port_8c.html#af410cacf6d6c44325b6637da95fc574d":[2,0,3,1,6,35],
-"gphoto2-port_8c.html#afac0b65253b3a37c961828e88b453733":[2,0,3,1,6,47],
-"gphoto2-port_8c.html#afb74e804c7fdb8897736f811d8e2adae":[2,0,3,1,6,28],
+"gphoto2-port_8c.html#addd41ab8b46062ec99cf07cafc12319d":[2,0,3,1,6,34],
+"gphoto2-port_8c.html#ae732282e180518c78a5854c023e20620":[2,0,3,1,6,35],
+"gphoto2-port_8c.html#af3b9610f316d951aa2a99b225dba748a":[2,0,3,1,6,49],
+"gphoto2-port_8c.html#af410cacf6d6c44325b6637da95fc574d":[2,0,3,1,6,36],
+"gphoto2-port_8c.html#afac0b65253b3a37c961828e88b453733":[2,0,3,1,6,48],
+"gphoto2-port_8c.html#afb74e804c7fdb8897736f811d8e2adae":[2,0,3,1,6,29],
 "gphoto2-port_8h.html":[2,0,3,0,6],
 "gphoto2-port_8h.html#a0077bb0c6918d27e5a36f27087e2c277":[2,0,3,0,6,29],
 "gphoto2-port_8h.html#a0154b05219003ef2fac2b490623613fb":[2,0,3,0,6,28],
@@ -248,6 +249,5 @@ var NAVTREEINDEX3 =
 "gphoto2-setting_8h.html#a4b50249c04f6a48156bad839827e67b7":[2,0,1,8,0],
 "gphoto2-setting_8h.html#a6100f1cf5f3e90c2491807b6db1796af":[2,0,1,8,1],
 "gphoto2-setting_8h_source.html":[2,0,1,8],
-"gphoto2-version_8c.html":[2,0,2,18],
-"gphoto2-version_8c.html#a039629a84ef4c735b1124901438a7468":[2,0,2,18,0]
+"gphoto2-version_8c.html":[2,0,2,18]
 };
