@@ -1,5 +1,6 @@
 var NAVTREEINDEX4 =
 {
+"gphoto2-version_8c.html#a039629a84ef4c735b1124901438a7468":[2,0,2,18,0],
 "gphoto2-version_8h.html":[2,0,1,9],
 "gphoto2-version_8h.html#a039629a84ef4c735b1124901438a7468":[2,0,1,9,0],
 "gphoto2-version_8h_source.html":[2,0,1,9],
@@ -248,6 +249,5 @@ var NAVTREEINDEX4 =
 "struct__CameraFilesystem.html#a2f676eede09ea213a0ef7e8711d6ddf3":[1,0,8,5],
 "struct__CameraFilesystem.html#a31e9fa7b813074658672a512b683a334":[1,0,8,1],
 "struct__CameraFilesystem.html#a32c4b277105e1a86ade9700dbc1cf891":[1,0,8,4],
-"struct__CameraFilesystem.html#a38fcb7940178fa609cd62b8aa9ea5c29":[1,0,8,10],
-"struct__CameraFilesystem.html#a48290da7bdd03d2a9f24a4bf6fa840dd":[1,0,8,12]
+"struct__CameraFilesystem.html#a38fcb7940178fa609cd62b8aa9ea5c29":[1,0,8,10]
 };
